from rdflib.URIRef import URIRef
from rdflib.Literal import Literal
from rdflib.BNode import BNode
from rdflib.Namespace import Namespace
from rdflib.constants import TYPE
from rdflib.TripleStore import TripleStore
from kraken.entrytypes.EntryBase import EntryBase
import bib2RDF
from kraken.tools.UniqueIdGenerator import getUniqueId
from kraken.entrytypes.Secondary import Secondary

class BibTeXEntry(EntryBase, Secondary):

  # the self description of the class
  namespaces = {}
  # the namespaces  
  namespaces["bibtex-rdf"] = "http://www.cs.ucf.edu/~lboloni/Programming/KrakenWeb/"
  BIBTEX = Namespace(namespaces["bibtex-rdf"]);

  #
  #   -----------  publication types
  #
  article = 'article'
  techreport = 'techreport'
  inproceedings = 'inproceedings'
  misc = 'misc'
  inbook = 'inbook'
  phdthesis = 'phdthesis'

  #
  #   -----------  properties
  #
  props = [
    "id",
    'author',
    'title',
    'booktitle',
    'chapter',
    'month',
    'year',
    'pages',
    'number',
    'journal',
    'volume',
    'publisher',
    'howpublished',
    'institution',
    'school',
    'note' ]
  
  def __init__(self):
      EntryBase.__init__(self)
      self.filecontents_source = ""
      self.__class__.defaultMapping = self.BIBTEX
      self.resourceURI = URIRef("bibtex://" + getUniqueId())
      # init all properties to ""
      for a in self.props:
          self.registerProperty(a, "")
      
      
  def __str__(self):
      return "Bibtex Entry:\n" + self.strFields(ignoreNone=True)
#
#  these are characteristic for the secondaries.
#

  def loadEntryFromNative(self, filepath):
    try:
        fd = open(filepath, 'r')
        self.filecontents_source = fd.readlines()
        fd.close()
    except:
        print 'Could not open file:', filepath
    washeddata = bib2RDF.bibtexwasher(self.filecontents_source)
    bib2RDF.bibtexdecoder(washeddata, self)

