import kraken.tools.TextUi as TextUi
from Filters import *
from Sorters import *
from Query import *
from Classifiers import *
from Limiter import *
import kraken.Constants
import os.path
import os
import pickle

def generateQuerySet(system, metadata):    
    # generate a query for every entry type
    opinionRanking = TextUi.confirm("Sort the entries by opinion ranking?")
    
    for entryType in metadata.getEntryTypes():
        que = Query()
        que.name = entryType        
        que.queryElements.append(getEntryTypeFilter(entryType))
        
        srtr = ReverseSorter()
        srtr.theSorter = EvaluationSorter()
        srtr.theSorter.propertyName = "Opinion.ranking"
        que.queryElements.append(srtr)
        
        queryFile = os.path.join(system.getProperty("filterDir"), 
            entryType + "_generated" + kraken.Constants.EXTENSION_QUERY)
        FILE = open(queryFile, "w")    
        pickle.dump(que, FILE)
        FILE.close()
    # generate a filter for unknown entry type:    
    que = Query()
    que.name = "Unknown entry"        
    que.queryElements.append(getUnknownEntryTypeFilter(metadata.getEntryTypes()))
        
    srtr = ReverseSorter()
    srtr.theSorter = EvaluationSorter()
    srtr.theSorter.propertyName = "Opinion.ranking"
    que.queryElements.append(srtr)
        
    queryFile = os.path.join(system.getProperty("filterDir"), 
         "UnknownEntry" + "_generated" + kraken.Constants.EXTENSION_QUERY)
    FILE = open(queryFile, "w")    
    pickle.dump(que, FILE)
    FILE.close()
    
        
    # Small tables
    for entryType in ["Conference", "ResearchIdea"]:
        que = Query()
        que.name = entryType        
        que.queryElements.append(getEntryTypeFilter(entryType))
        
        srtr = ReverseSorter()
        srtr.theSorter = EvaluationSorter()
        srtr.theSorter.propertyName = "Opinion.ranking"
        que.queryElements.append(srtr)

        lim = Limiter()
        lim.limit = 20
        que.queryElements.append(lim)
        
        queryFile = os.path.join(system.getProperty("filterDir"), 
            entryType + "_smalltable" + kraken.Constants.EXTENSION_QUERY)
        FILE = open(queryFile, "w")    
        pickle.dump(que, FILE)
        FILE.close()
        
        
        
def getEntryTypeFilter(entryType):
        flt = OrFilter()
        
        flt2 = ContainsAllFilter()
        flt2.propertyName = "entryTypes"
        flt2.filterValue = [entryType]
        flt.filters.append(flt2)
        
        # this is needed for legacy reasons
        flt2 = ContainsAllFilter()
        flt2.propertyName = "keywords"
        flt2.filterValue = [entryType]
        flt.filters.append(flt2)
 
        return flt
        
def getUnknownEntryTypeFilter(entryTypes):
        flt = NotFilter()
        
        flt2 = ContainsAnyFilter()
        flt2.propertyName = "entryTypes"
        flt2.filterValue = entryTypes
        flt.flt = flt2        
 
        return flt        
