"""
Python-PDI - Library for Personal Data Interchange.
Copyright (C) 2002-2003 Peter Gebauer

A small test example on how to create new components.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
version 2 as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
"""
from pdi.vcalendar import VCalendar
from pdi.core import Component
import pdi.parser

class VWhackyCalendar(VCalendar):
    """
    This is a non-standards compliant calendar with some added subcomponents and properties.
    It's only an example, nobody uses this whacky format for real (that I know of).

    We will add a subcomponent named VWHACKY and a property named WHACKYNESS for that subcomponent.
    """
    
    def __init__(self, parent = None):
        """
        @type   parent: L{pdi.core.Component}
        @param  parent: The parent component, if any. May be omitted or None if it is a top-level component.
        """
        super(VWhackyCalendar, self).__init__(parent)
        self.registerComponents([VWhacky], pdi.core.RULE_MUST)

class VWhacky(Component):
    """A whacky test component"""

    def __init__(self, parent = None):
        """
        @type   parent: L{pdi.core.Component}
        @param  parent: The parent component, if any. May be omitted or None if it is a top-level component.
        """
        super(VWhacky, self).__init__(parent)
        self.registerProperties(['WHACKY'], pdi.core.RULE_MUST)

def main():
    calendar = pdi.parser.fromFile("whackytest.ics", VWhackyCalendar())
    # Dump it!
    print(calendar)

if __name__ == '__main__':
    main()
